@@ -11,11 +11,17 @@ from web3.middleware import geth_poa_middleware
 import secure_web3.lib.abi_lib
 import secure_web3.lib.style
 from secure_web3.lib.wallet_manager import WalletManager
+from secure_web3.lib import load_networks
+
 
 
 class Web3RpcNotConfigured(Exception):
     pass
 
+class WalletFileNotFound(Exception):
+    pass
+
+
 
 class SecureWeb3:
     def __init__(self, wallet_file: str = None, network: str = 'ethereum',
@@ -123,18 +129,24 @@ class SecureWeb3:
         if not endpoint:
             self.printer.error('Could not find network, is it configured?')
             return
+        self.endpoint = endpoint
         w3 = web3.Web3(web3.HTTPProvider(endpoint))
         if network_name == 'polygon':
             poa = True
         if poa:
             w3.middleware_onion.inject(geth_poa_middleware)
-        if w3.isConnected():
+        if hasattr(w3, 'isConnected'):
+            is_conn = w3.isConnected()
+        else:
+            is_conn = w3.is_connected
+        if is_conn:
             self.printer.good(f'Successfully switched to {network_name}')
         else:
             self.printer.error(f'Web3 could not connect to endpoint at {endpoint}')
 
 
 if __name__ == '__main__':
+    networks = load_networks.load_networks()
     args = argparse.ArgumentParser('Secure Web3 Cli')
     args.add_argument('-i', '--init', dest='init_wallet', type=str, nargs=1,
                       default=None, help='Initialize this new wallet')
@@ -145,7 +157,7 @@ if __name__ == '__main__':
     args.add_argument('-l', '--lock', dest='lock_wallet', action='store_true',
                       help='Lock all open wallets.')
     args.add_argument('-n', '--network', type=str, default='ethereum',
-                      choices=['ethereum', 'polygon', 'bsc', 'aurora'])
+                      choices=networks)
     args = args.parse_args()
     dotenv.load_dotenv()
 
